/*
  SDL_image:  An example image loading library for use with SDL
  Copyright (C) 1997-2012 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
module org.libsdl.image;

import org.libsdl.error;
import org.libsdl.rwops;
import org.libsdl.stdinc;
import org.libsdl.video;
import org.libsdl.versions;

immutable uint SDL_IMAGE_MAJOR_VERSION = 1;
immutable uint SDL_IMAGE_MINOR_VERSION = 2;
immutable uint SDL_IMAGE_PATCHLEVEL    = 12;

void SDL_IMAGE_VERSION(ref SDL_version ver)
{
	ver.major = SDL_IMAGE_MAJOR_VERSION;
	ver.minor = SDL_IMAGE_MINOR_VERSION;
	ver.patch = SDL_IMAGE_PATCHLEVEL;
}

extern (C)
{
	const(SDL_version)* IMG_Linked_Version();
}

enum IMG_InitFlags : uint
{
	IMG_INIT_JPG  = 0x00000001,
	IMG_INIT_PNG  = 0x00000002,
	IMG_INIT_TIF  = 0x00000004,
	IMG_INIT_WEBP = 0x00000008
}

alias IMG_InitFlags.IMG_INIT_JPG IMG_INIT_JPG;
alias IMG_InitFlags.IMG_INIT_PNG IMG_INIT_PNG;
alias IMG_InitFlags.IMG_INIT_TIF IMG_INIT_TIF;

extern (C)
{
	int IMG_Init(int flags);
	void IMG_Quit();
	SDL_Surface* IMG_LoadTyped_RW(SDL_RWops* src, int freesrc, char* type);
	SDL_Surface* IMG_Load(const(char)* file);
	SDL_Surface* IMG_Load_RW(SDL_RWops* src, int freesrc);
	int IMG_InvertAlpha(int on);
	int IMG_isICO(SDL_RWops* src);
	int IMG_isCUR(SDL_RWops* src);
	int IMG_isBMP(SDL_RWops* src);
	int IMG_isGIF(SDL_RWops* src);
	int IMG_isJPG(SDL_RWops* src);
	int IMG_isLBM(SDL_RWops* src);
	int IMG_isPCX(SDL_RWops* src);
	int IMG_isPNG(SDL_RWops* src);
	int IMG_isPNM(SDL_RWops* src);
	int IMG_isTIF(SDL_RWops* src);
	int IMG_isXCF(SDL_RWops* src);
	int IMG_isXPM(SDL_RWops* src);
	int IMG_isXV(SDL_RWops* src);
	int IMG_isWEBP(SDL_RWops* src);
	SDL_Surface* IMG_LoadICO_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadCUR_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadBMP_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadGIF_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadJPG_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadLBM_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadPCX_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadPNG_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadPNM_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadTGA_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadTIF_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadXCF_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadXPM_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadXV_RW(SDL_RWops* src);
	SDL_Surface* IMG_LoadWEBP_RW(SDL_RWops* src);
	SDL_Surface* IMG_ReadXPMFromArray(char** xpm);
}

alias SDL_SetError IMG_SetError;
alias SDL_GetError IMG_GetError;

