/*
  SDL_ttf:  A companion library to SDL for working with TrueType (tm) fonts
  Copyright (C) 2001-2012 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
module org.libsdl.ttf;

import org.libsdl.error;
import org.libsdl.rwops;
import org.libsdl.stdinc;
import org.libsdl.video;
import org.libsdl.versions;

immutable uint SDL_TTF_MAJOR_VERSION = 2;
immutable uint SDL_TTF_MINOR_VERSION = 0;
immutable uint SDL_TTF_PATCHLEVEL    = 11;

void SDL_TTF_VERSION(ref SDL_version ver)
{
	ver.major = SDL_TTF_MAJOR_VERSION;
	ver.minor = SDL_TTF_MINOR_VERSION;
	ver.patch = SDL_TTF_PATCHLEVEL;
}

immutable uint TTF_MAJOR_VERSION = SDL_TTF_MAJOR_VERSION;
immutable uint TTF_MINOR_VERSION = SDL_TTF_MINOR_VERSION;
immutable uint TTF_PATCHLEVEL    = SDL_TTF_PATCHLEVEL;

alias SDL_TTF_VERSION TTF_VERSION;

extern (C)
{
	const(SDL_version)* TTF_Linked_Version();
}

immutable int UNICODE_BOM_NATIVE  = 0xFEFF;
immutable int UNICODE_BOM_SWAPPED = 0xFFFE;

extern (C)
{
	void TTF_ByteSwappedUNICODE(int swapped);
}

struct TTF_Font {}

extern (C)
{
	int TTF_Init();
	TTF_Font* TTF_OpenFont(const(char)* file, int ptsize);
	TTF_Font* TTF_OpenFontIndex(const(char)* file, int ptsize, int index);
	TTF_Font* TTF_OpenFontRW(SDL_RWops* src, int freesrc, int ptsize);
	TTF_Font* TTF_OpenFontIndexRW(SDL_RWops* src, int freesrc, int ptsize, int index);
}

immutable int TTF_STYLE_NORMAL        = 0x00;
immutable int TTF_STYLE_BOLD          = 0x01;
immutable int TTF_STYLE_ITALIC        = 0x02;
immutable int TTF_STYLE_UNDERLINE     = 0x04;
immutable int TTF_STYLE_STRIKETHROUGH = 0x08;

extern (C)
{
	int TTF_GetFontStyle(const(TTF_Font)* font);
	void TTF_SetFontStyle(TTF_Font* font, int style);
	int TTF_GetFontOutline(const(TTF_Font)* font);
	void TTF_SetFontOutline(TTF_Font* font, int outline);
}

immutable int TTF_HINTING_NORMAL = 0;
immutable int TTF_HINTING_LIGHT  = 1;
immutable int TTF_HINTING_MONO   = 2;
immutable int TTF_HINTING_NONE   = 3;

extern (C)
{
	int TTF_GetFontHinting(const(TTF_Font)* font);
	void TTF_SetFontHinting(TTF_Font* font, int hinting);
	int TTF_FontHeight(const(TTF_Font)* font);
	int TTF_FontAscent(const(TTF_Font)* font);
	int TTF_FontDescent(const(TTF_Font)* font);
	int TTF_FontLineSkip(const(TTF_Font)* font);
	int TTF_GetFontKerning(const(TTF_Font)* font);
	void TTF_SetFontKerning(TTF_Font* font, int allowed);
	int TTF_FontFaces(const(TTF_Font)* font);
	int TTF_FontFaceIsFixedWidth(const(TTF_Font)* font);
	char* TTF_FontFaceFamilyName(const(TTF_Font)* font);
	char* TTF_FontFaceStyleName(const(TTF_Font)* font);
	int TTF_GlyphIsProvided(const(TTF_Font)* font, wchar ch);
	int TTF_GlyphMetrics(TTF_Font* font, wchar ch, int* minx, int* maxx, int* miny, int* maxy, int* advance);
	int TTF_SizeText(TTF_Font* font, const(char)* text, int* w, int* h);
	int TTF_SizeUTF8(TTF_Font* font, const(char)* text, int* w, int* h);
	int TTF_SizeUNICODE(TTF_Font* font, const(wchar)* text, int* w, int* h);
	SDL_Surface* TTF_RenderText_Solid(TTF_Font* font, const(char)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderUTF8_Solid(TTF_Font* font, const(char)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderUNICODE_Solid(TTF_Font* font, const(wchar)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderGlyph_Solid(TTF_Font* font, wchar ch, SDL_Color fg);
	SDL_Surface* TTF_RenderText_Shaded(TTF_Font* font, const(char)* text, SDL_Color fg, SDL_Color bg);
	alias TTF_RenderText_Shaded TTF_RenderText;
	SDL_Surface* TTF_RenderUTF8_Shaded(TTF_Font* font, const(char)* text, SDL_Color fg, SDL_Color bg);
	alias TTF_RenderUTF8_Shaded TTF_RenderUTF8;
	SDL_Surface* TTF_RenderUNICODE_Shaded(TTF_Font* font, const(wchar)* text, SDL_Color fg, SDL_Color bg);
	alias TTF_RenderUNICODE_Shaded TTF_RenderUNICODE;
	SDL_Surface* TTF_RenderGlyph_Shaded(TTF_Font* font, wchar ch, SDL_Color fg, SDL_Color bg);
	SDL_Surface* TTF_RenderText_Blended(TTF_Font* font, const(char)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderUTF8_Blended(TTF_Font* font, const(char)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderUNICODE_Blended(TTF_Font* font, const(wchar)* text, SDL_Color fg);
	SDL_Surface* TTF_RenderGlyph_Blended(TTF_Font* font, wchar ch, SDL_Color fg);
	void TTF_CloseFont(TTF_Font* font);
	void TTF_Quit();
	int TTF_WasInit();
	int TTF_GetFontKerningSize(TTF_Font* font, int prev_index, int index);
}

alias SDL_SetError TTF_SetError;
alias SDL_GetError TTF_GetError;

